@@ -1,7 +1,7 @@
 #!/bin/bash
 VERSION='0.6'
 #
-# Copyright (C) 2003-2009  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2003-2010  Ola Lundqvist <opal@debian.org>
 # Copyright (C) 2009       Stefan Tomanek <stefan@pico.ruhr.de>
 # Copyright (C) 2007       Tijs van Dam <tijsvd@bluescraper.com>
 # Copyright (C) 2007       Jochen Voss <voss@seehuhn.de>
@@ -244,7 +244,7 @@ parse_args ()
 			;;
 		    --hostname)
 			case "$2" in
-			    [a-z0-9]*([a-z0-9_-])[a-z0-9])
+			    [a-z0-9]?(*([a-z0-9_-])[a-z0-9]))
 				VHOST="$2"
 				;;
 			    *)
