@@ -1,7 +1,7 @@
 #!/bin/bash
 VERSION='0.6'
 #
-# Copyright (C) 2002-2008  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2002-2010  Ola Lundqvist <opal@debian.org>
 # Copyright (C) 2006       Miroslav Kure <kurem@upcase.inf.upol.cz>
 # Copyright (C) 2002       Mark Lawrence <nomad@null.net>
 # Copyright (C) 2002       Paul Sladen   <vserver@paul.sladen.org>
@@ -185,7 +185,7 @@ parse_args ()
 			;;
 		    --hostname)
 			case "$2" in
-			    [a-z0-9]*([a-z0-9_-])[a-z0-9])
+			    [a-z0-9]?(*([a-z0-9_-])[a-z0-9]))
 				VHOST="$2"
 				;;
 			    *)
